
.. image:: https://img.shields.io/pypi/pyversions/anyconfig-configobj-backend.svg
   :target: https://pypi.python.org/pypi/anyconfig-configobj-backend/
   :alt: [Python versions]

.. image:: https://img.shields.io/pypi/l/anyconfig-configobj-backend.svg
   :target: https://pypi.python.org/pypi/anyconfig-configobj-backend/
   :alt: MIT License

.. image:: https://github.com/ssato/python-anyconfig-configobj-backend/workflows/Tests/badge.svg
   :target: https://github.com/ssato/python-anyconfig-configobj-backend/actions?query=workflow%3ATests
   :alt: [Github Actions: Test status]

.. image:: https://img.shields.io/coveralls/ssato/python-anyconfig-configobj-backend.svg
   :target: https://coveralls.io/r/ssato/python-anyconfig-configobj-backend
   :alt: Coverage Status

.. image:: https://codecov.io/gh/ssato/python-anyconfig-configobj-backend/branch/next/graph/badge.svg?token=CEHaIGm60z
   :target: https://codecov.io/gh/ssato/python-anyconfig-configobj-backend
   :alt: [Codecov Status]

.. image:: https://readthedocs.org/projects/python-anyconfig-configobj-backend/badge/?version=latest
   :target: http://python-anyconfig-configobj-backend.readthedocs.io/en/latest/?badge=latest
   :alt: Doc Status

.. vim:sw=2:ts=2:et:
